@ECHO OFF
REM
REM \ldsu\bin\do_export.bat - script to do a single LDSU export
REM
REM	P1 - Name of export subdirectory (e.g. export_xxx )
REM	P2 - Name of foreign directory export file (e.g. xfer_out\xxx.dat )
REM	     (Optional - export file not copied anywhere if not specified)
REM	P3 - Optional name for ldsu_config.dat in subdirectory
REM
REM	The following files must already exist in the export subdirectory:
REM
REM		ldsu_config.dat or P3
REM		export.rdf (or name specified in config file)
REM
REM	The following files are created as a result of running this procedure:
REM
REM		export.txt - LDSU export file. May be Converted or Copied to P2.
REM		ldsu.log - full LDSU stdout log
REM
REM	The following files are optional in the export subdirectory:
REM
REM		export_post.bat - procedure to process export.txt (possibly to
REM			      convert to 'P2').  If procedure doesn't exist,
REM			      export.txt is simply copied to 'P2' (if specified)
REM

IF NOT DEFINED ldsubindir SET ldsubindir=%~dp0%

IF "%1"=="" GOTO USAGE
IF %1=="" GOTO USAGE
GOTO L1
:USAGE
ECHO Usage: %0 ldsu_subdirectory_name [xfer_out_filename] [config_file]
SET ldsu_status=1
GOTO LEND1
:L1
ECHO ----------------------------------------------------------------------
%ldsubindir%timestamp "%1 started at" 1

REM	set default directory to the export subdirectory

PUSHD %1
IF NOT errorlevel 1 GOTO L2
ECHO LDSU EXPORT Failed - Invalid Subdirectory: %1
SET ldsu_status=1
GOTO LEND1
:L2

REM	Run LDSU to export the data

ECHO exporting export.txt from Directory
CALL %ldsubindir%do_ldsu EXPORT %3

REM	If LDSU failed, send mail to administrator

IF %ldsu_status%==0 GOTO L3
ECHO LDSU EXPORT Failed
CALL %ldsubindir%do_send_mail ldsu.log "%1 failure"
GOTO L6
:L3

REM	Else run the post processor script or copy the file (if specified)

set ldsu_export_file=..\%2
if %ldsu_export_file%==..\"" set ldsu_export_file=..\
if %ldsu_export_file%==..\ set ldsu_export_file=""
IF NOT EXIST export_post.bat GOTO L4
SET ldsu_status=0
CALL export_post export.txt %ldsu_export_file%
IF %ldsu_status%==0 GOTO L6
ECHO LDSU EXPORT Failed - Error Running EXPORT_POST
ECHO Error Running EXPORT_POST > t.t
CALL %ldsubindir%do_send_mail  t.t "%1 failure"
DEL /Q t.t
SET ldsu_status=1
GOTO LEND
:L4
IF %ldsu_export_file%=="" GOTO L6
ECHO copying export.txt to %ldsu_export_file%
COPY export.txt %ldsu_export_file% >nul
IF NOT errorlevel 1 GOTO L6
ECHO LDSU EXPORT Failed - Error copying export.txt to %ldsu_export_file%
ECHO Error copying export.txt to %ldsu_export_file% > t.t
CALL %ldsubindir%do_send_mail  t.t "%1 failure"
DEL /Q t.t
SET ldsu_status=1
GOTO LEND

:L6
%ldsubindir%timestamp "%1 finished at" 0
ECHO ----------------------------------------------------------------------

:LEND
POPD
:LEND1
