@ECHO OFF
REM
REM \ldsu\bin\do_import.bat - script to do a single LDSU import
REM
REM	P1 - Name of import subdirectory (e.g. import_xxx )
REM	P2 - Name of foreign directory import file (e.g. xfer_in\xxx.dat )
REM		(optional - assume file in place if not specified)
REM	P3 - Optional name for ldsu_config.dat in subdirectory
REM
REM	The following files must already exist in the import subdirectory:
REM
REM		ldsu_config.dat or P3
REM		import.rdf (or name specified in config file)
REM		import.txt - import file. (if P2 not specified)
REM
REM	The following files are optional in the import subdirectory:
REM
REM		import_pre.bat - procedure to convert 'P2' to import.txt.  If
REM			         procedure doesn't exist, file is simply copied.
REM			         Only used if 'P2' is specified.
REM
REM	The following files are created as a result of running this procedure:
REM
REM		import.txt - import file. Converted or Copied from 'P2'.
REM			(if P2 specified. If not, this file must already exist)
REM		import.log - transaction log file (also copied to logs/'P1'.log)
REM		ldsu.log - full LDSU stdout log
REM

IF NOT DEFINED ldsubindir SET ldsubindir=%~dp0%

IF "%1"=="" GOTO USAGE
IF %1=="" GOTO USAGE
GOTO L1
:USAGE
ECHO Usage: %0 ldsu_subdirectory_name [xfer_in_filename] [config_file]
SET ldsu_status=1
GOTO LEND1
:L1
ECHO ----------------------------------------------------------------------
%ldsubindir%timestamp "%1 started at" 1

REM	set default directory to the import subdirectory

PUSHD %1
IF NOT errorlevel 1 GOTO L2
ECHO LDSU IMPORT Failed - Invalid Subdirectory: %1
SET ldsu_status=1
GOTO LEND1
:L2

REM	If Specified, Convert or Copy the input file to the LDSU input format

IF "%2"=="" GOTO L6
IF %2=="" GOTO L6
IF NOT EXIST ..\%2 GOTO L5
IF NOT EXIST import_pre.bat GOTO L4

:L3
SET ldsu_status=0
CALL import_pre ..\%2 import.txt
IF %ldsu_status%==0 GOTO L6
ECHO LDSU IMPORT Failed - Error Running IMPORT_PRE
ECHO Error Running IMPORT_PRE > t.t
CALL %ldsubindir%do_send_mail  t.t "%1 failure"
DEL /Q t.t
SET ldsu_status=1
GOTO LEND

:L4
ECHO copying ..\%2 to import.txt
COPY ..\%2 import.txt >nul
IF NOT errorlevel 1 GOTO L6
ECHO LDSU IMPORT Failed - Error copying ..\%2 to import.txt
ECHO Error copying ..\%2 to import.txt > t.t
CALL %ldsubindir%do_send_mail  t.t "%1 failure"
DEL /Q t.t
SET ldsu_status=1
GOTO LEND

:L5
ECHO LDSU IMPORT Failed - ..\%2 file not found
ECHO ..\%2 file not found > t.t
CALL %ldsubindir%do_send_mail  t.t "%1 failure"
DEL /Q t.t
SET ldsu_status=1
GOTO LEND

REM	Run LDSU to import the data

:L6
ECHO importing import.txt to Directory
CALL %ldsubindir%do_ldsu IMPORT %3

REM	If LDSU failed, send mail to administrator, else archive input file

IF %ldsu_status%==0 GOTO L8
ECHO LDSU IMPORT Failed
CALL %ldsubindir%do_send_mail ldsu.log "%1 failure"
GOTO L9
:L8
IF "%2"=="" GOTO L9
IF %2=="" GOTO L9
CALL %ldsubindir%do_archive ..\%2
:L9

REM	Copy the transaction log to the logs directory

IF NOT EXIST import.log GOTO L10
IF NOT EXIST ..\logs GOTO L10
CALL %ldsubindir%do_archive ..\logs\%1.log
COPY import.log ..\logs\%1.log >nul
:L10

%ldsubindir%timestamp "%1 finished at" 0
ECHO ----------------------------------------------------------------------

:LEND
POPD
:LEND1
